c ######################################################################
c #
c #                  YBCO-123 PROPERTIES PACKAGE
c #                  ------------------------------
c # Contains functions for the calculation of the thermo-physical
c # properties of YBCO-123
c #
c ######################################################################

c ######################################################################
      real function dYBCO123(T)
c ######################################################################
c #
c # Density of YBCO-123
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable        I/O      meaning                             units
c # --------------------------------------------------------------------
c #   T             x        absolute temperature                  K
c #   dYBCO123        x      density                            kg/m**3
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dYBCO123 = 0.0
c *

      return
      end
c ######################################################################
      real function cYBCO123(T,B,Angle,Epslon)
c ######################################################################
c #
c # Specific heat of YBCO-123
c #
c # Range: Tmin <= T <= Tmax
c #
c #                        References
c #                        ----------
c #
c # variable        I/O      meaning                             units
c # --------------------------------------------------------------------
c #   T             x        absolute temperature                K
c #   B             x        magnetic field                      T
c #   Angle         x        field angle w/r to ab plane         degrees
c #   Epslon        x        strain                              -
c #   cYBCO123        x      specific heat                       J/Kg K
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,Angle,Epslon
c * fit variables

c * local variables

c *
      cYBCO123 = 0.0
c *
      return
      end
c ######################################################################
      real function kYBCO123(T)
c ######################################################################
c #
c # Thermal conductivity of YBCO-123
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable        I/O      meaning                             units
c # --------------------------------------------------------------------
c #   T             x        absolute temperature                  K
c #   kYBCO123        x      thermal conductivity                W/m K
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      kYBCO123 = 0.0
c *

      return
      end
c ######################################################################
      real function rYBCO123(T)
c ######################################################################
c #
c # Electrical resistivity of YBCO-123
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable        I/O      meaning                             units
c # --------------------------------------------------------------------
c #   T             x        absolute temperature                  K
c #   rYBCO123        x      resistivity                         Ohm m
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      rYBCO123 = 0.0
c *

      return
      end
c ######################################################################
      real function TcYBCO123(B,Angle,Epslon)
c ######################################################################
c #
c # Critical temperature, in K, for YBCO-123 as a function of applied
c # field
c #
c #                        References
c #                        ----------
c #
c # variable        I/O      meaning                             units
c # --------------------------------------------------------------------
c #   B             x        magnetic field                      T
c #   Angle         x        field angle w/r to ab plane         degrees
c #   Epslon        x        strain                              -
c #   TcYBCO123       x      critical temperature                K
c #
c # Other functions called: NONE
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     B,Angle,Epslon
c * fit variables      

c * local variables

c *      
      TcYBCO123 = 0.0

c *
      return
      end
c ######################################################################
      real function BcYBCO123(T,Epslon)
c ######################################################################
c #
c # Upper critical field, in T, for YBCO-123 as a function of field
c #
c #                        References
c #                        ----------
c #
C # variable       I/O       meaning                             units
C # --------------------------------------------------------------------
C #   T            x         temperature                         K
c #   Epslon       x         strain                              -
c #   BcYBCO123      x       critical field                      T
c #
c # Other functions called: NONE
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     T,Epslon
c * fit variables      

c * local variables

c *      
      BcYBCO123 = 0.0

c *
      return
      end
c ######################################################################
      real function JcYBCO123(T,B,Angle,Epslon)
c ######################################################################
c #
c # Critical (non-copper) current density, in A/m**2, for YBCO-123 as
c # a function of temperature and field. 
c #
c #                        References
c #                        ----------
c #
c #
C # variable       I/O       meaning                             units
C # --------------------------------------------------------------------
C #   T            x         temperature                         K
c #   B            x         magnetic field                      T
c #   Angle        x         field angle w/r to ab plane         degrees
c #   Epslon       x         strain                              -
c #   JcYBCO123      x       critical current density            A/m**2
c #
c # Other functions called: NONE
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     T,B,Angle,Epslon
c * fit variables      

c * local variables

c *      
      JcYBCO123 = 0.0

c *
      return
      end
c ######################################################################
      real function TcsYBCO123(B,Angle,Epslon,Jop)
c ######################################################################
C #
C # Current sharing temperature, in K, for YBCO-123 as a function of 
c # field and operating current density.
C #
C # variable       I/O       meaning                             units
C # --------------------------------------------------------------------
C #   B            x         magnetic field                      T
c #   Angle        x         field angle w/r to ab plane         degrees
c #   Epslon       x         strain                              -
C #   Jop          x         operating current density           A/m**2
c #   TcsYBCO123     x       current sharing temperature         K
c #
c # Other functions called: 
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     B,Angle,Epslon,Jop
c * fit variables      

c * local variables

c *      
      TcsYBCO123 = 0.0

c *
      return
      end
